ChainNegative

Enum ChainNegative 

pub enum ChainNegative {
    HostnameMismatch {
        wrong_hostname: String,
    },
    UnknownCa,
    ExpiredLeaf,
    NotYetValidLeaf,
    ExpiredIntermediate,
    NotYetValidIntermediate,
    IntermediateNotCa,
    IntermediateWrongKeyUsage,
    RevokedLeaf,
}
Types of invalid certificate chains for negative testing.

Variants



HostnameMismatch

Leaf cert has a SAN that doesn’t match the expected hostname.

Fields

wrong_hostname: String

The wrong hostname to put in the leaf SAN.



UnknownCa

Chain is anchored to a different (unknown) root certificate identity. This variant intentionally reuses the same underlying RSA key material and changes certificate-level identity fields for the root certificate.



ExpiredLeaf

Leaf certificate is expired.



NotYetValidLeaf

Leaf certificate is not yet valid.



ExpiredIntermediate

Intermediate certificate is expired.



NotYetValidIntermediate

Intermediate certificate is not yet valid.



IntermediateNotCa

Intermediate certificate no longer claims CA status.



IntermediateWrongKeyUsage

Intermediate certificate claims CA status but lacks CA signing usage.



RevokedLeaf

Leaf certificate is listed as revoked in a CRL signed by the intermediate CA.

Implementations

Source

impl ChainNegative

pub fn variant_name(&self) -> String

Variant name for cache keys.

pub fn apply_to_spec(&self, base_spec: &ChainSpec) -> ChainSpec

Apply this negative variant to a chain spec.