pub enum NotBeforeOffset {
DaysAgo(u32),
DaysFromNow(u32),
}Expand description
Offset for the not_before field.
Variants
DaysAgo(u32)
Certificate is valid starting from this many days in the past.
DaysFromNow(u32)
Certificate is valid starting from this many days in the future.